Class: SunshineConversationsClient::ImageMessage

Inherits:
Object
  • Object
show all
Defined in:
lib/sunshine-conversations-client/models/image_message.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ImageMessage

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 84

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `SunshineConversationsClient::ImageMessage` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `SunshineConversationsClient::ImageMessage`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = 'image'
  end

  if attributes.key?(:'media_url')
    self.media_url = attributes[:'media_url']
  end

  if attributes.key?(:'media_type')
    self.media_type = attributes[:'media_type']
  end

  if attributes.key?(:'media_size')
    self.media_size = attributes[:'media_size']
  end

  if attributes.key?(:'alt_text')
    self.alt_text = attributes[:'alt_text']
  end

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  end

  if attributes.key?(:'html_text')
    self.html_text = attributes[:'html_text']
  end

  if attributes.key?(:'markdown_text')
    self.markdown_text = attributes[:'markdown_text']
  end

  if attributes.key?(:'actions')
  end

  if attributes.key?(:'attachment_id')
    self.attachment_id = attributes[:'attachment_id']
  end
end

Instance Attribute Details

#actionsObject

Array of message actions.



39
40
41
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 39

def actions
  @actions
end

#alt_textObject

An optional description of the image for accessibility purposes. The field will be saved by default with the file name as the value.



27
28
29
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 27

def alt_text
  @alt_text
end

#attachment_idObject

An identifier used by Sunshine Conversations for internal purposes.



42
43
44
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 42

def attachment_id
  @attachment_id
end

#html_textObject

HTML text content of the message. Can be provided in place of text. Cannot be used with markdownText. If no text is provided, will be converted to text upon reception to be displayed on channels that do not support rich text. See [rich text](docs.smooch.io/guide/structured-messages/rich-text) documentation for more information.



33
34
35
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 33

def html_text
  @html_text
end

#markdown_textObject

Markdown text content of the message. Can be provided in place of text. Cannot be used with htmlText. Will be converted to htmlText upon reception. If converted htmlText exceeds 4096 characters, the message will be rejected. If no text is provided, will be converted to text upon reception to be displayed on channels that do not support rich text. See [rich text](docs.smooch.io/guide/structured-messages/rich-text) documentation for more information.



36
37
38
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 36

def markdown_text
  @markdown_text
end

#media_sizeObject

The size of the media in bytes.



24
25
26
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 24

def media_size
  @media_size
end

#media_typeObject

The type of media.



21
22
23
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 21

def media_type
  @media_type
end

#media_urlObject

The URL for media, such as an image, attached to the message. <aside class="notice">Note that for private attachments an authorization header is required to access the mediaUrl. See [configuring private attachments for messaging](developer.zendesk.com/documentation/zendesk-web-widget-sdks/messaging_private_attachments/) guide for more details.</aside>



18
19
20
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 18

def media_url
  @media_url
end

#textObject

The text content of the message.



30
31
32
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 30

def text
  @text
end

#typeObject

The type of message.



15
16
17
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 15

def type
  @type
end

Class Method Details

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 45

def self.attribute_map
  {
    :'type' => :'type',
    :'media_url' => :'mediaUrl',
    :'media_type' => :'mediaType',
    :'media_size' => :'mediaSize',
    :'alt_text' => :'altText',
    :'text' => :'text',
    :'html_text' => :'htmlText',
    :'markdown_text' => :'markdownText',
    :'actions' => :'actions',
    :'attachment_id' => :'attachmentId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



254
255
256
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 254

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



77
78
79
80
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 77

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 61

def self.openapi_types
  {
    :'type' => :'String',
    :'media_url' => :'String',
    :'media_type' => :'String',
    :'media_size' => :'Float',
    :'alt_text' => :'String',
    :'text' => :'String',
    :'html_text' => :'String',
    :'markdown_text' => :'String',
    :'actions' => :'Array<Action>',
    :'attachment_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 224

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      type == o.type &&
      media_url == o.media_url &&
      media_type == o.media_type &&
      media_size == o.media_size &&
      alt_text == o.alt_text &&
      text == o.text &&
      html_text == o.html_text &&
      markdown_text == o.markdown_text &&
      actions == o.actions &&
      attachment_id == o.attachment_id
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 282

def _deserialize(type, value)
  case type.to_sym
  when :DateTime
    DateTime.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    SunshineConversationsClient.const_get(type).build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 351

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 261

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  self.class.openapi_types.each_pair do |key, type|
    if type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end # or else data not found in attributes(hash), not an issue as the data can be optional
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


241
242
243
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 241

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



247
248
249
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 247

def hash
  [type, media_url, media_type, media_size, alt_text, text, html_text, markdown_text, actions, attachment_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 141

def list_invalid_properties
  invalid_properties = Array.new
  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @media_url.nil?
    invalid_properties.push('invalid value for "media_url", media_url cannot be nil.')
  end

  if !@media_type.nil? && @media_type.to_s.length > 128
    invalid_properties.push('invalid value for "media_type", the character length must be smaller than or equal to 128.')
  end

  if !@alt_text.nil? && @alt_text.to_s.length > 128
    invalid_properties.push('invalid value for "alt_text", the character length must be smaller than or equal to 128.')
  end

  if !@html_text.nil? && @html_text.to_s.length > 4096
    invalid_properties.push('invalid value for "html_text", the character length must be smaller than or equal to 4096.')
  end

  if !@markdown_text.nil? && @markdown_text.to_s.length > 4096
    invalid_properties.push('invalid value for "markdown_text", the character length must be smaller than or equal to 4096.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



327
328
329
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 327

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 333

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end
    
    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



321
322
323
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 321

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



172
173
174
175
176
177
178
179
180
# File 'lib/sunshine-conversations-client/models/image_message.rb', line 172

def valid?
  return false if @type.nil?
  return false if @media_url.nil?
  return false if !@media_type.nil? && @media_type.to_s.length > 128
  return false if !@alt_text.nil? && @alt_text.to_s.length > 128
  return false if !@html_text.nil? && @html_text.to_s.length > 4096
  return false if !@markdown_text.nil? && @markdown_text.to_s.length > 4096
  true
end