Class: SunshineConversationsClient::UsersApi
- Inherits:
-
Object
- Object
- SunshineConversationsClient::UsersApi
- Defined in:
- lib/sunshine-conversations-client/api/users_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_user(app_id, user_create_body, opts = {}) ⇒ UserResponse
Create User Creates a new user.
-
#create_user_with_http_info(app_id, user_create_body, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Create User Creates a new user.
-
#delete_user(app_id, user_id_or_external_id, opts = {}) ⇒ Object
Delete User Delete a user, its clients and its conversation history.
-
#delete_user_personal_information(app_id, user_id_or_external_id, opts = {}) ⇒ UserResponse
Delete User Personal Information Delete a user’s personal information.
-
#delete_user_personal_information_with_http_info(app_id, user_id_or_external_id, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Delete User Personal Information Delete a user’s personal information.
-
#delete_user_with_http_info(app_id, user_id_or_external_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Delete User Delete a user, its clients and its conversation history.
-
#get_user(app_id, user_id_or_external_id, opts = {}) ⇒ UserResponse
Get User Fetches an individual user.
-
#get_user_with_http_info(app_id, user_id_or_external_id, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Get User Fetches an individual user.
-
#initialize(api_client = ApiClient.default) ⇒ UsersApi
constructor
A new instance of UsersApi.
-
#sync_user(app_id, zendesk_id, opts = {}) ⇒ UserResponse
Synchronize User Synchronize a messaging user with its core Zendesk user counterpart.
-
#sync_user_with_http_info(app_id, zendesk_id, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Synchronize User Synchronize a messaging user with its core Zendesk user counterpart.
-
#update_user(app_id, user_id_or_external_id, user_update_body, opts = {}) ⇒ UserResponse
Update User Updates a user.
-
#update_user_with_http_info(app_id, user_id_or_external_id, user_update_body, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Update User Updates a user.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ UsersApi
16 17 18 |
# File 'lib/sunshine-conversations-client/api/users_api.rb', line 16 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
14 15 16 |
# File 'lib/sunshine-conversations-client/api/users_api.rb', line 14 def api_client @api_client end |
Instance Method Details
#create_user(app_id, user_create_body, opts = {}) ⇒ UserResponse
Create User Creates a new user.
25 26 27 28 |
# File 'lib/sunshine-conversations-client/api/users_api.rb', line 25 def create_user(app_id, user_create_body, opts = {}) data, _status_code, _headers = create_user_with_http_info(app_id, user_create_body, opts) data end |
#create_user_with_http_info(app_id, user_create_body, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Create User Creates a new user.
36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/sunshine-conversations-client/api/users_api.rb', line 36 def create_user_with_http_info(app_id, user_create_body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.create_user ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling UsersApi.create_user" end # verify the required parameter 'user_create_body' is set if @api_client.config.client_side_validation && user_create_body.nil? fail ArgumentError, "Missing the required parameter 'user_create_body' when calling UsersApi.create_user" end # resource path local_var_path = '/v2/apps/{appId}/users'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(user_create_body) # return_type return_type = opts[:return_type] || 'UserResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth', 'bearerAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#create_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_user(app_id, user_id_or_external_id, opts = {}) ⇒ Object
Delete User Delete a user, its clients and its conversation history. The user is considered completely deleted once the user:delete webhook is fired. To only delete a user’s personal information, see [Delete User Personal Information](#operation/deleteUserPersonalInformation).
95 96 97 98 |
# File 'lib/sunshine-conversations-client/api/users_api.rb', line 95 def delete_user(app_id, user_id_or_external_id, opts = {}) data, _status_code, _headers = delete_user_with_http_info(app_id, user_id_or_external_id, opts) data end |
#delete_user_personal_information(app_id, user_id_or_external_id, opts = {}) ⇒ UserResponse
Delete User Personal Information Delete a user’s personal information. Calling this API will clear givenName, surname, email and avatarUrl and every custom property for the specified user. For every client owned by the user, it will also clear displayName, avatarUrl and any channel specific information stored in the info and raw fields. Calling this API doesn’t delete the user’s conversation history. To fully delete the user, see [Delete User](#operation/deleteUser).
163 164 165 166 |
# File 'lib/sunshine-conversations-client/api/users_api.rb', line 163 def delete_user_personal_information(app_id, user_id_or_external_id, opts = {}) data, _status_code, _headers = delete_user_personal_information_with_http_info(app_id, user_id_or_external_id, opts) data end |
#delete_user_personal_information_with_http_info(app_id, user_id_or_external_id, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Delete User Personal Information Delete a user’s personal information. Calling this API will clear `givenName`, `surname`, `email` and `avatarUrl` and every custom property for the specified user. For every client owned by the user, it will also clear `displayName`, `avatarUrl` and any channel specific information stored in the info and raw fields. Calling this API doesn’t delete the user’s conversation history. To fully delete the user, see [Delete User](#operation/deleteUser).
174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/sunshine-conversations-client/api/users_api.rb', line 174 def delete_user_personal_information_with_http_info(app_id, user_id_or_external_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.delete_user_personal_information ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling UsersApi.delete_user_personal_information" end # verify the required parameter 'user_id_or_external_id' is set if @api_client.config.client_side_validation && user_id_or_external_id.nil? fail ArgumentError, "Missing the required parameter 'user_id_or_external_id' when calling UsersApi.delete_user_personal_information" end # resource path local_var_path = '/v2/apps/{appId}/users/{userIdOrExternalId}/personalinformation'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)).sub('{' + 'userIdOrExternalId' + '}', CGI.escape(user_id_or_external_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'UserResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth', 'bearerAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#delete_user_personal_information\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_user_with_http_info(app_id, user_id_or_external_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Delete User Delete a user, its clients and its conversation history. The user is considered completely deleted once the `user:delete` webhook is fired. To only delete a user’s personal information, see [Delete User Personal Information](#operation/deleteUserPersonalInformation).
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/sunshine-conversations-client/api/users_api.rb', line 106 def delete_user_with_http_info(app_id, user_id_or_external_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.delete_user ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling UsersApi.delete_user" end # verify the required parameter 'user_id_or_external_id' is set if @api_client.config.client_side_validation && user_id_or_external_id.nil? fail ArgumentError, "Missing the required parameter 'user_id_or_external_id' when calling UsersApi.delete_user" end # resource path local_var_path = '/v2/apps/{appId}/users/{userIdOrExternalId}'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)).sub('{' + 'userIdOrExternalId' + '}', CGI.escape(user_id_or_external_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'Object' # auth_names auth_names = opts[:auth_names] || ['basicAuth', 'bearerAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#delete_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_user(app_id, user_id_or_external_id, opts = {}) ⇒ UserResponse
Get User Fetches an individual user.
231 232 233 234 |
# File 'lib/sunshine-conversations-client/api/users_api.rb', line 231 def get_user(app_id, user_id_or_external_id, opts = {}) data, _status_code, _headers = get_user_with_http_info(app_id, user_id_or_external_id, opts) data end |
#get_user_with_http_info(app_id, user_id_or_external_id, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Get User Fetches an individual user.
242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 |
# File 'lib/sunshine-conversations-client/api/users_api.rb', line 242 def get_user_with_http_info(app_id, user_id_or_external_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.get_user ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling UsersApi.get_user" end # verify the required parameter 'user_id_or_external_id' is set if @api_client.config.client_side_validation && user_id_or_external_id.nil? fail ArgumentError, "Missing the required parameter 'user_id_or_external_id' when calling UsersApi.get_user" end # resource path local_var_path = '/v2/apps/{appId}/users/{userIdOrExternalId}'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)).sub('{' + 'userIdOrExternalId' + '}', CGI.escape(user_id_or_external_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'UserResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth', 'bearerAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#get_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#sync_user(app_id, zendesk_id, opts = {}) ⇒ UserResponse
Synchronize User Synchronize a messaging user with its core Zendesk user counterpart. Messaging users are separate objects linked to a core Zendesk user record by zendeskId. It is possible for changes to be made to the core Zendesk user record in a way that causes the messaging user to fall out of sync. The core Zendesk user might change their primary email, for example. This endpoint can be used to update the messaging user with the profile.givenName, profile.surname, externalId, and primary email identity of its core Zendesk user counterpart. Note that only the primary email identity of the core Zendesk user will be synchronized, and it will be set on the identities array, not in the profile. Note also that in some circumstances, a single call to this API might produce changes on more than one messaging user. If the externalId or email being synchronized already exists on a different messaging user within the account, the conflict will be resolved by merging those messaging users together, if possible. If a conflicting messaging user is already linked to a core Zendesk user by zendeskId it cannot be merged. In this case, the conflicting externalId or email will instead be removed and reassigned to the messaging user that is being synchronized
299 300 301 302 |
# File 'lib/sunshine-conversations-client/api/users_api.rb', line 299 def sync_user(app_id, zendesk_id, opts = {}) data, _status_code, _headers = sync_user_with_http_info(app_id, zendesk_id, opts) data end |
#sync_user_with_http_info(app_id, zendesk_id, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Synchronize User Synchronize a messaging user with its core Zendesk user counterpart. Messaging users are separate objects linked to a core Zendesk user record by `zendeskId`. It is possible for changes to be made to the core Zendesk user record in a way that causes the messaging user to fall out of sync. The core Zendesk user might change their primary email, for example. This endpoint can be used to update the messaging user with the `profile.givenName`, `profile.surname`, `externalId`, and primary email identity of its core Zendesk user counterpart. Note that only the primary email identity of the core Zendesk user will be synchronized, and it will be set on the `identities` array, not in the `profile`. Note also that in some circumstances, a single call to this API might produce changes on more than one messaging user. If the `externalId` or email being synchronized already exists on a different messaging user within the account, the conflict will be resolved by merging those messaging users together, if possible. If a conflicting messaging user is already linked to a core Zendesk user by `zendeskId` it cannot be merged. In this case, the conflicting `externalId` or email will instead be removed and reassigned to the messaging user that is being synchronized
310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/sunshine-conversations-client/api/users_api.rb', line 310 def sync_user_with_http_info(app_id, zendesk_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.sync_user ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling UsersApi.sync_user" end # verify the required parameter 'zendesk_id' is set if @api_client.config.client_side_validation && zendesk_id.nil? fail ArgumentError, "Missing the required parameter 'zendesk_id' when calling UsersApi.sync_user" end # resource path local_var_path = '/v2/apps/{appId}/users/{zendeskId}/sync'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)).sub('{' + 'zendeskId' + '}', CGI.escape(zendesk_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] # return_type return_type = opts[:return_type] || 'UserResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth', 'bearerAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#sync_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#update_user(app_id, user_id_or_external_id, user_update_body, opts = {}) ⇒ UserResponse
Update User Updates a user.
368 369 370 371 |
# File 'lib/sunshine-conversations-client/api/users_api.rb', line 368 def update_user(app_id, user_id_or_external_id, user_update_body, opts = {}) data, _status_code, _headers = update_user_with_http_info(app_id, user_id_or_external_id, user_update_body, opts) data end |
#update_user_with_http_info(app_id, user_id_or_external_id, user_update_body, opts = {}) ⇒ Array<(UserResponse, Integer, Hash)>
Update User Updates a user.
380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/sunshine-conversations-client/api/users_api.rb', line 380 def update_user_with_http_info(app_id, user_id_or_external_id, user_update_body, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: UsersApi.update_user ...' end # verify the required parameter 'app_id' is set if @api_client.config.client_side_validation && app_id.nil? fail ArgumentError, "Missing the required parameter 'app_id' when calling UsersApi.update_user" end # verify the required parameter 'user_id_or_external_id' is set if @api_client.config.client_side_validation && user_id_or_external_id.nil? fail ArgumentError, "Missing the required parameter 'user_id_or_external_id' when calling UsersApi.update_user" end # verify the required parameter 'user_update_body' is set if @api_client.config.client_side_validation && user_update_body.nil? fail ArgumentError, "Missing the required parameter 'user_update_body' when calling UsersApi.update_user" end # resource path local_var_path = '/v2/apps/{appId}/users/{userIdOrExternalId}'.sub('{' + 'appId' + '}', CGI.escape(app_id.to_s)).sub('{' + 'userIdOrExternalId' + '}', CGI.escape(user_id_or_external_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' header_params['Content-Type'] = @api_client.select_header_content_type(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:body] || @api_client.object_to_http_body(user_update_body) # return_type return_type = opts[:return_type] || 'UserResponse' # auth_names auth_names = opts[:auth_names] || ['basicAuth', 'bearerAuth'] = opts.merge( :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: UsersApi#update_user\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |